==> jc-1.4.0.tar.gz: java/awt/geom/Area__24AreaIterator__24IteratorSegment.h <==
// class java.awt.geom.Area$AreaIterator$IteratorSegment

// class file dependencies
// @dep_class 46667e1bd25dec4a java_awt_geom_Area__24AreaIterator__24IteratorSegment
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_geom_Area__24AreaIterator__24IteratorSegment_H_
#define _JC_java_awt_geom_Area__24AreaIterator__24IteratorSegment_H_

// Forward structure declarations
struct _jc_java_awt_geom_Area__24AreaIterator$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_refs	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_refs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_nonrefs	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_nonrefs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$refs	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$refs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$nonrefs	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$nonrefs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$object	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$object;

typedef const struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vmethods	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vmethods;
typedef const struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtable	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtable;
typedef const struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtype	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtype;

// Constructors
extern void _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$method$_init$dec55dd218292ec8(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$object *, struct _jc_java_awt_geom_Area__24AreaIterator$object *);

// Virtual methods structure
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vmethods {
};

// Vtable
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vmethods	java_awt_geom_Area__24AreaIterator__24IteratorSegment;
};

// Vtype
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_refs {
	_jc_double_array	*coords;
	struct _jc_java_awt_geom_Area__24AreaIterator$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$refs {
    _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_refs	java_awt_geom_Area__24AreaIterator__24IteratorSegment;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_nonrefs {
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_nonrefs	java_awt_geom_Area__24AreaIterator__24IteratorSegment;
};

// Object instance structure
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$object {
	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtype	*vtype;
	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtype _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Area__24AreaIterator__24IteratorSegment, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$class_object;

#endif	/* _JC_java_awt_geom_Area__24AreaIterator__24IteratorSegment_H_ */

==> jc-1.4.6.tar.gz: java/awt/geom/Area__24AreaIterator__24IteratorSegment.h <==
// class java.awt.geom.Area$AreaIterator$IteratorSegment

// class file dependencies
// @dep_class 22afbb42d6ab9475 java_awt_geom_Area__24AreaIterator__24IteratorSegment
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_geom_Area__24AreaIterator__24IteratorSegment_H_
#define _JC_java_awt_geom_Area__24AreaIterator__24IteratorSegment_H_

// Forward structure declarations
struct _jc_java_awt_geom_Area__24AreaIterator$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_refs	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_refs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_nonrefs	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_nonrefs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$refs	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$refs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$nonrefs	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$nonrefs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$object	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$object;

typedef const struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vmethods	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vmethods;
typedef const struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtable	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtable;
typedef const struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtype	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtype;

// Constructors
extern void _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$method$_init$dec55dd218292ec8(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$object *, struct _jc_java_awt_geom_Area__24AreaIterator$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vmethods {
};

// Vtable
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vmethods	java_awt_geom_Area__24AreaIterator__24IteratorSegment;
};

// Vtype
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_refs {
	_jc_double_array	*coords;
	struct _jc_java_awt_geom_Area__24AreaIterator$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$refs {
    _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_refs	java_awt_geom_Area__24AreaIterator__24IteratorSegment;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_nonrefs {
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$sub_nonrefs	java_awt_geom_Area__24AreaIterator__24IteratorSegment;
};

// Object instance structure
struct _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$object {
	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtype	*vtype;
	_jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$vtype _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Area__24AreaIterator__24IteratorSegment, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Area__24AreaIterator__24IteratorSegment$class_object;

#endif	/* _JC_java_awt_geom_Area__24AreaIterator__24IteratorSegment_H_ */
